#!/usr/bin/python3

import apt
import time
import subprocess
import os

def check_for_updates():
    try:
        # APT Cache laden
        cache = apt.Cache()
        cache.open(None)
        cache.upgrade()  # Füllt den Cache mit den zu aktualisierenden Paketen

        # Liste der zu aktualisierenden Pakete prüfen
        upgradable_packages = [pkg.name for pkg in cache if pkg.is_upgradable]

        if upgradable_packages:
            # Benachrichtigung anzeigen
            message = f"{len(upgradable_packages)} Updates verfügbar: {', '.join(upgradable_packages[:5])}"
            subprocess.run(['notify-send', 'Es sind Updates verfügbar', message])
            
            print(message)  # Für Debugging in der Konsole
        else:
            print("Keine neuen Updates verfügbar.")
    except Exception as e:
        print(f"Fehler beim Prüfen der Updates: {e}")

if __name__ == "__main__":
    try:
        print("Update-Checker gestartet. Drücken Sie STRG+C zum Beenden.")
        while True:
            check_for_updates()
            time.sleep(6 * 60 * 60)
    except KeyboardInterrupt:
        print("\nSkript vom Benutzer unterbrochen. Beende...")

